/*
 * Copyright(C) OASIS(R) 2006,2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.
 */

/** @file
 * This file contains the SCA ServiceReference class declaration.
 * @author SCA-C-C++ TC
 * @version 1.1
 * @date 4 March 2010
 */

#ifndef _oasis_sca_ServiceReference_h_
#define _oasis_sca_ServiceReference_h_

#include "oasis/sca/ServiceProxy.h"
#include "oasis/sca/RefCountingPointer.h"

namespace oasis {
    namespace sca {

        /**
         * Defines the ServiceReference interface
         */
        class ServiceReference {
            public:

                /**
                 * Returns a service proxy implementing the interface defined for a ServiceReference
                 * @return Pointer to a ServiceProxy implementing the interface of the ServiceReference.
                 */
                virtual ServiceProxyPtr getService() const = 0;


                /**
                 * Returns a service proxy implementing the callback interface defined for a ServiceReference.
                 * @return Pointer to a ServiceProxy implementing the callback interface of the ServiceReference.
                 *         This will be NULL if no callback interface is defined.
                 */
                virtual ServiceProxyPtr getCallback() const = 0;
        };


        /**
         * RefCounting Pointer for a ServiceReference.
         */
        typedef RefCountingPointer<ServiceReference> ServiceReferencePtr;

    } // namespace sca
} // namespace oasis

#endif /* _oasis_sca_ServiceReference_h_ */
